==> ZS_AdvancedViz_test1-0.1.tar.gz: ZS_AdvancedViz_test1-0.1/setup.py <==

from distutils.core import setup
setup(
  name = 'ZS_AdvancedViz_test1',         # How you named your package folder (MyLib)
  packages = ['ZS_AdvancedViz_test1'],   # Chose the same as "name"
  version = '0.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Python-based visualization library which provides ready to use functions to render different types of charts',   # Give a short description about your library
  author = 'Prachi',                   # Type in your name
  author_email = 'prachirane95@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/Prachi95/ZS_AdvancedViz_test1',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/Prachi95/ZS_AdvancedViz_test1/archive/v_01.tar.gz',    # I explain this later on
  keywords = ['SOME', 'MEANINGFULL', 'KEYWORDS'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'pandas',
          'numpy',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)

==> ZS_AdvancedViz_test1-5.0.tar.gz: ZS_AdvancedViz_test1-5.0/setup.py <==

from distutils.core import setup
setup(
  name = 'ZS_AdvancedViz_test1',         # How you named your package folder (MyLib)
  packages = ['ZS_AdvancedViz_test1'],   # Chose the same as "name"
  version = '5.0',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Python-based visualization library which provides ready to use functions to render different types of charts',   # Give a short description about your library
  author = 'Prachi',                   # Type in your name
  author_email = 'prachirane95@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/Prachi95/ZS_AdvancedViz_test1',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/Prachi95/ZS_AdvancedViz_test1/archive/5.0.tar.gz',    # I explain this later on
  keywords = ['SOME', 'MEANINGFULL', 'KEYWORDS'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'pandas',
          'numpy',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
